@@ -38,7 +38,7 @@ _pkg_config = {
     'py_version':         0x020710,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+    'sip_config_args':    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro',
     'sip_inc_dir':        '/usr/include/python2.7',
     'sip_module_dir':     '/usr/lib/python2.7/site-packages',
     'sip_root_dir':       '/usr/lib/python2.7/site-packages',
@@ -51,7 +51,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt',
+    'CFLAGS':                   '-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
@@ -100,7 +100,7 @@ _default_macros = {
     'INCDIR':                   '',
     'INCDIR_OPENGL':            '/usr/X11R6/include',
     'INCDIR_X11':               '/usr/X11R6/include',
-    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro',
     'LFLAGS_CONSOLE':           '',
     'LFLAGS_CONSOLE_DLL':       '',
     'LFLAGS_DEBUG':             '',
